<?php 

namespace Schaffen\SerasaRemessa\Cnab600;

class Shipping {
    /**
     * @var Header Registro do tipo Header
     */
    private $header;

    /**
     * @var array Lista de detalhes da remessa
     */
    private $details = [];

    /**
     * @var Trailer Registro do tipo Trailer
     */
    private $trailer;

    /**
     * @param array $config Dados da empresa 
     * @param array $persons Pessoas a serem negativadas
     */
    public function __construct(array $config, array $persons) {
        $this->header = new Header($config);
        
        $sequence = 2;
        foreach($persons as $person) {
            $this->details[] = new Detail($this->header->getCnpjBranchDigit(), $person, $sequence);
            $sequence++;
        }

        $this->trailer = new Trailer($sequence);
    }

    /**
     * @return Header
     */
    public function getHeader() {
        return $this->header;
    }

    /**
     * @return string String da remessa
     */
    public function make() {
        $headerString = $this->makeHeader();
        $detailsString = $this->makeDetails();
        $trailerString = $this->makeTrailer();

        return $headerString . $detailsString . $trailerString;
    }

    /**
     * @return string String do Cabeçalho
     */
    private function makeHeader() {
        return $this->header->toString() . "\n";
    }

    /**
     * @return string String dos Detlalhes
     */
    private function makeDetails() {
        $detailsString = '';
        foreach( $this->details as $detail ) {
            $detailsString .= $detail->toString() . "\n";
        }

        return $detailsString;
    }

    /**
     * @return string String do Trailer
     */
    private function makeTrailer() {
        return $this->trailer->toString();
    }
}